from setuptools import setup, find_packages

setup(
    name='snns',
    version='0.0.0',
    url='https://open-neuromorphic.org',
    author='Author Name',
    author_email='author@gmail.com',
    description='Description of my package',
    packages=find_packages(),    
)
